==> react-native-sendotp-1.0.0.tgz: package/README.md <==
# Send OTP React-Native Sdk!

**The SendOtp Verification SDK makes verifying phone numbers easy. SDK supports the verification of phone numbers via SMS & Calls.**


## Getting started

Login or create account at MSG91 to use sendOTP services.

Get your authKey
After login at MSG91 follow below steps to get your authkey
* Select API option available on panel.
* If you are first time user then generate new authkey.
* copy authKey & keep it enable
* DLT_TE_ID to get from Network provider

## Installing

``` 
$ npm install react-native-sendotp
```

## Example

```
import * as sendOTP from "react-native-sendotp";

// Optional parameters should be set before generateOTP function
// Send OTP
sendOTP.generateOTP(TEMPLATE_ID, MOBILE_NUMBER_WITH_COUNTRY_CODE, TOKEN)

// Resend/Retry OTP
sendOTP.resendOTP(TYPE) // TYPE can be "voice" or "text", default value is "voice"

// Verify OTP
sendOTP.verifyOTP(ENTER_OTP_RECEIVED_BY_USER)

// Set all values to the default 
sendOTP.setToDefaults()

```

## Optional Parameters

**Note** - All the optional parameters should be set before _generateOTP function call.

* **setVerifyWithoutOtp(1 or 0)** [1 for ON, 0 for OFF; Mobile Number Automatically Verified if its Mobile Network is ON]

* **setOtp(OTP)** [OTP you want to send]

* **setUserIp(IP)** [User IP]

* **setEmail(EMAIL)** [Email ID on which you want to send OTP]

* **setOtpLength(OTP_LENGTH)** [Number of digits in OTP (default : 4, min : 4, max : 9)]

* **setOtpExpireInMinute(TIME_IN_MINUTE)** [Expiry of OTP to verify, in minutes (default : 1 day, min : 1 minute)]

* **setExtraParams(VALUE)** [Here you can pass the variables created in the SendOTP template.]

* **setUnicodeEnable(1 or 0)** [Enter 1 if sending SMS in languages other than English, for english pass 0]


## License

```
Copyright 2022 MSG91
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```

==> react-native-sendotp-1.0.2.tgz: package/README.md <==
# Send OTP React-Native Sdk!

**The SendOtp Verification SDK makes verifying phone numbers easy. SDK supports the verification of phone numbers via SMS & Calls.**


## Getting started

Login or create account at MSG91 to use sendOTP services.

Get your authKey
After login at MSG91 follow below steps to get your authkey
* Select API option available on panel.
* If you are first time user then generate new authkey.
* copy authKey & keep it enable
* DLT_TE_ID to get from Network provider

## Installing

``` 
$ npm install @msg91comm/react-native-sendotp
```

## Example

```
import * as sendOTP from "@msg91comm/react-native-sendotp";

// Optional parameters should be set before generateOTP function
// Send OTP
sendOTP.generateOTP(TEMPLATE_ID, MOBILE_NUMBER_WITH_COUNTRY_CODE, TOKEN)

// Resend/Retry OTP
sendOTP.resendOTP(TYPE) // TYPE can be "voice" or "text", default value is "voice"

// Verify OTP
sendOTP.verifyOTP(ENTER_OTP_RECEIVED_BY_USER)

// Set all values to the default 
sendOTP.setToDefaults()

```

## Optional Parameters

**Note** - All the optional parameters should be set before _generateOTP function call.

* **setVerifyWithoutOtp(1 or 0)** [1 for ON, 0 for OFF; Mobile Number Automatically Verified if its Mobile Network is ON]

* **setOtp(OTP)** [OTP you want to send]

* **setUserIp(IP)** [User IP]

* **setEmail(EMAIL)** [Email ID on which you want to send OTP]

* **setOtpLength(OTP_LENGTH)** [Number of digits in OTP (default : 4, min : 4, max : 9)]

* **setOtpExpireInMinute(TIME_IN_MINUTE)** [Expiry of OTP to verify, in minutes (default : 1 day, min : 1 minute)]

* **setExtraParams(VALUE)** [Here you can pass the variables created in the SendOTP template.]

* **setUnicodeEnable(1 or 0)** [Enter 1 if sending SMS in languages other than English, for english pass 0]


## License

```
Copyright 2022 MSG91
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
